@@ -16,6 +16,18 @@
 dpt() {
     local REAL TMP ES
     REAL=`command which dpt`
+    ES=0
+
+    case "$1" in
+        cd|co|checkout)
+            # continue below
+            ;;
+        *)
+            $REAL "$@" || ES=$?
+            return $ES
+            ;;
+    esac
+
     TMP=`mktemp -d --suffix=.dpt`
     if [ -n "${BASH:-}" ]; then
         trap "command rm -rf '$TMP'" RETURN
@@ -27,7 +39,6 @@ dpt() {
     set +m
     tee "$TMP/out" < "$TMP/pipe" &
     )
-    ES=0
     $REAL "$@" > "$TMP/pipe" || ES=$?
 
     [ -e "$TMP/out" ] || return $ES
